@@ -119,7 +119,7 @@ class EntityReportDataProcessor(DataProcessor):
 
             return True
 
-        if entity.description:
+        if entity.description and not entity.description.__root__ == "":
             return True
         return False
 
@@ -171,11 +171,19 @@ class EntityReportDataProcessor(DataProcessor):
         refined_data = defaultdict(lambda: defaultdict(dict))
         for entity in self.fetch_data():
             data_blob_for_entity = {}
-            team = (
-                self._get_team(entity.owner)
-                if not isinstance(entity, User)
-                else self._get_team(entity.teams)
-            )
+            try:
+                team = (
+                    self._get_team(entity.owner)
+                    if not isinstance(entity, User)
+                    else self._get_team(entity.teams)
+                )
+            except Exception:
+                logger.debug(traceback.format_exc())
+                self.processor_status.failed(
+                    entity.name.__root__, "Error retrieving team"
+                )
+                continue
+
             try:
                 entity_tier = get_entity_tier_from_tags(entity.tags)
             except AttributeError:
@@ -230,6 +238,8 @@ class EntityReportDataProcessor(DataProcessor):
                     str(entity_tier)
                 ].update(data_blob_for_entity_counter)
 
+            self.processor_status.scanned(entity.name.__root__)
+
         return refined_data
 
     def process(self) -> Iterable[ReportData]:
