@@ -8,10 +8,14 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
-
+"""
+Abstract Processor definition to build a Workflow
+"""
 from abc import ABCMeta, abstractmethod
-from dataclasses import dataclass, field
-from typing import Any, Generic, List
+from dataclasses import dataclass
+from typing import Any, Generic, List, Optional
+
+from pydantic import Field
 
 from metadata.generated.schema.entity.services.connections.metadata.openMetadataConnection import (
     OpenMetadataConnection,
@@ -19,34 +23,42 @@ from metadata.generated.schema.entity.services.connections.metadata.openMetadata
 from metadata.ingestion.api.closeable import Closeable
 from metadata.ingestion.api.common import Entity
 from metadata.ingestion.api.status import Status
+from metadata.utils.logger import ingestion_logger
+
+logger = ingestion_logger()
 
 
-@dataclass
 class ProcessorStatus(Status):
-    records = 0
-    warnings: List[Any] = field(default_factory=list)
-    failures: List[Any] = field(default_factory=list)
+    records: List[str] = Field(default_factory=list)
 
     def processed(self, record: Any):
-        self.records += 1
+        self.records.append(record)
 
     def warning(self, info: Any) -> None:
         self.warnings.append(info)
 
-    def failure(self, info: Any) -> None:
-        self.failures.append(info)
 
+class ProfilerProcessorStatus(Status):
+    entity: Optional[str] = None
 
-@dataclass
-class ProfilerProcessorStatus(ProcessorStatus):
-    entity: str = None
+    def scanned(self, record: Any) -> None:
+        self.records.append(record)
 
-    def failure(self, column: str, metric: str, reason: str) -> None:
-        self.failures.append({self.entity: {column: {metric: {reason}}}})
+    def failed_profiler(self, error: str, stack_trace: Optional[str] = None) -> None:
+        self.failed(self.entity if self.entity else "", error, stack_trace)
 
 
 @dataclass
 class Processor(Closeable, Generic[Entity], metaclass=ABCMeta):
+    """
+    Processor class
+    """
+
+    status: ProcessorStatus
+
+    def __init__(self):
+        self.status = ProcessorStatus()
+
     @classmethod
     @abstractmethod
     def create(
@@ -58,9 +70,8 @@ class Processor(Closeable, Generic[Entity], metaclass=ABCMeta):
     def process(self, *args, **kwargs) -> Entity:
         pass
 
-    @abstractmethod
     def get_status(self) -> ProcessorStatus:
-        pass
+        return self.status
 
     @abstractmethod
     def close(self) -> None:
