@@ -14,14 +14,15 @@ Python API REST wrapper and helpers
 import datetime
 import time
 import traceback
-from typing import Callable, List, Optional, Union
+from copy import deepcopy
+from typing import Any, Callable, Dict, List, Optional, Union
 
 import requests
 from requests.exceptions import HTTPError
 
 from metadata.config.common import ConfigModel
 from metadata.ingestion.ometa.credentials import URL, get_api_version
-from metadata.ingestion.ometa.utils import ometa_logger
+from metadata.utils.logger import ometa_logger
 
 logger = ometa_logger()
 
@@ -101,6 +102,7 @@ class ClientConfig(ConfigModel):
     access_token: Optional[str] = None
     expires_in: Optional[int] = None
     auth_header: Optional[str] = None
+    extra_headers: Optional[dict] = None
     raw_data: Optional[bool] = False
     allow_redirects: Optional[bool] = False
     auth_token_mode: Optional[str] = "Bearer"
@@ -135,6 +137,7 @@ class REST:
         api_version: str = None,
         headers: dict = None,
     ):
+        # pylint: disable=too-many-locals
         if not headers:
             headers = {"Content-type": "application/json"}
         base_url = base_url or self._base_url
@@ -157,6 +160,20 @@ class REST:
             self.config.auth_header
         ] = f"{self._auth_token_mode} {self.config.access_token}"
 
+        # Merge extra headers if provided.
+        # If a header value is provided in modulo string format and matches an existing header,
+        # the value will be set to that value.
+        # Example: "Proxy-Authorization": "%(Authorization)s"
+        # This will result in the Authorization value being set for the Proxy-Authorization Extra Header
+        if self.config.extra_headers:
+            extra_headers: Dict[str, str] = self.config.extra_headers
+            extra_headers = {k: (v % headers) for k, v in extra_headers.items()}
+            logger.debug(
+                "Extra headers provided '%s'",
+                self._mask_authorization_headers(extra_headers),
+            )
+            headers = {**headers, **extra_headers}
+
         opts = {
             "headers": headers,
             # Since we allow users to set endpoint URL via env var,
@@ -167,6 +184,8 @@ class REST:
             "verify": self._verify,
         }
 
+        masked_opts = self._mask_authorization_headers(opts)
+
         method_key = "params" if method.upper() == "GET" else "data"
         opts[method_key] = data
 
@@ -175,7 +194,7 @@ class REST:
         while retry >= 0:
             try:
                 logger.debug("URL %s, method %s", url, method)
-                logger.debug("Data %s", opts)
+                logger.debug("Data %s", masked_opts)
                 return self._one_request(method, url, opts, retry)
             except RetryException:
                 retry_wait = self._retry_wait * (total_retries - retry + 1)
@@ -187,6 +206,7 @@ class REST:
                 )
                 time.sleep(retry_wait)
                 retry -= 1
+        return None
 
     def _one_request(self, method: str, url: URL, opts: dict, retry: int):
         """
@@ -196,9 +216,19 @@ class REST:
         Returns the body json in the 200 status.
         """
         retry_codes = self._retry_codes
-        resp = self._session.request(method, url, **opts)
         try:
+            resp = self._session.request(method, url, **opts)
             resp.raise_for_status()
+
+            if resp.text != "":
+                try:
+                    return resp.json()
+                except Exception as exc:
+                    logger.debug(traceback.format_exc())
+                    logger.warning(
+                        f"Unexpected error while returning response {resp} in json format - {exc}"
+                    )
+
         except HTTPError as http_error:
             # retry if we hit Rate Limit
             if resp.status_code in retry_codes and retry > 0:
@@ -209,19 +239,22 @@ class REST:
                     raise APIError(error, http_error) from http_error
             else:
                 raise
+        except requests.ConnectionError as conn:
+            # Trying to solve https://github.com/psf/requests/issues/4664
+            try:
+                return self._session.request(method, url, **opts).json()
+            except Exception as exc:
+                logger.debug(traceback.format_exc())
+                logger.warning(
+                    f"Unexpected error while retrying after a connection error - {exc}"
+                )
+                raise conn
         except Exception as exc:
             logger.debug(traceback.format_exc())
             logger.warning(
                 f"Unexpected error calling [{url}] with method [{method}]: {exc}"
             )
-        if resp.text != "":
-            try:
-                return resp.json()
-            except Exception as exc:
-                logger.debug(traceback.format_exc())
-                logger.warning(
-                    f"Unexpected error while returing response {resp} in json format - {exc}"
-                )
+
         return None
 
     def get(self, path, data=None):
@@ -305,3 +338,12 @@ class REST:
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.close()
+
+    def _mask_authorization_headers(self, opts: Dict[str, Any]) -> Dict[str, Any]:
+        if opts and opts.get("headers"):
+            if self.config.auth_header and opts["headers"][self.config.auth_header]:
+                masked_opts = deepcopy(opts)
+                if self.config.auth_header and opts["headers"][self.config.auth_header]:
+                    masked_opts["headers"][self.config.auth_header] = "********"
+                return masked_opts
+        return opts
