@@ -38,10 +38,10 @@ from metadata.generated.schema.metadataIngestion.workflow import (
 )
 from metadata.generated.schema.metadataIngestion.workflow import SourceConfig
 from metadata.generated.schema.type.entityLineage import EntitiesEdge
-from metadata.generated.schema.type.entityReference import EntityReference
 from metadata.ingestion.ometa.client import REST
 from metadata.ingestion.ometa.mixins.lineage_mixin import OMetaLineageMixin
-from metadata.ingestion.ometa.utils import format_name, ometa_logger
+from metadata.ingestion.ometa.utils import format_name
+from metadata.utils.logger import ometa_logger
 
 logger = ometa_logger()
 
@@ -152,5 +152,5 @@ class OMetaMlModelMixin(OMetaLineageMixin):
                 )
                 for key, value in model.get_params().items()
             ],
-            service=EntityReference(id=service.id, type="mlmodelService"),
+            service=service.fullyQualifiedName,
         )
