@@ -11,6 +11,7 @@
 """
 Credentials helper module
 """
+import base64
 import json
 import os
 import tempfile
@@ -21,7 +22,9 @@ from cryptography.hazmat.primitives import serialization
 from metadata.generated.schema.security.credentials.gcsCredentials import (
     GCSCredentials,
     GCSCredentialsPath,
-    GCSValues,
+)
+from metadata.generated.schema.security.credentials.gcsValues import (
+    GcsCredentialsValues,
 )
 from metadata.utils.logger import utils_logger
 
@@ -52,7 +55,7 @@ def validate_private_key(private_key: str) -> None:
         serialization.load_pem_private_key(private_key.encode(), password=None)
     except ValueError as err:
         msg = f"Cannot serialise key: {err}"
-        raise InvalidPrivateKeyException(msg)
+        raise InvalidPrivateKeyException(msg) from err
 
 
 def create_credential_tmp_file(credentials: dict) -> str:
@@ -61,27 +64,28 @@ def create_credential_tmp_file(credentials: dict) -> str:
     :param credentials: dictionary to store
     :return: path to find the file
     """
-    with tempfile.NamedTemporaryFile(delete=False) as fp:
+    with tempfile.NamedTemporaryFile(delete=False) as temp_file:
         cred_json = json.dumps(credentials, indent=4, separators=(",", ": "))
-        fp.write(cred_json.encode())
+        temp_file.write(cred_json.encode())
 
-        return fp.name
+        return temp_file.name
 
 
-def build_google_credentials_dict(gcs_values: GCSValues) -> Dict[str, str]:
+def build_google_credentials_dict(gcs_values: GcsCredentialsValues) -> Dict[str, str]:
     """
-    Given GCSValues, build a dictionary as the JSON file
+    Given GcsCredentialsValues, build a dictionary as the JSON file
     downloaded from GCS with the service_account
     :param gcs_values: GCS credentials
     :return: Dictionary with credentials
     """
-
     private_key_str = gcs_values.privateKey.get_secret_value()
+    # adding the replace string here to escape line break if passed from env
+    private_key_str = private_key_str.replace("\\n", "\n")
     validate_private_key(private_key_str)
 
     return {
         "type": gcs_values.type,
-        "project_id": gcs_values.projectId,
+        "project_id": gcs_values.projectId.__root__,
         "private_key_id": gcs_values.privateKeyId,
         "private_key": private_key_str,
         "client_email": gcs_values.clientEmail,
@@ -98,9 +102,6 @@ def set_google_credentials(gcs_credentials: GCSCredentials) -> None:
     Set GCS credentials environment variable
     :param gcs_credentials: GCSCredentials
     """
-    if os.environ.get(GOOGLE_CREDENTIALS):
-        return
-
     if isinstance(gcs_credentials.gcsConfig, GCSCredentialsPath):
         os.environ[GOOGLE_CREDENTIALS] = str(gcs_credentials.gcsConfig.__root__)
         return
@@ -111,7 +112,7 @@ def set_google_credentials(gcs_credentials: GCSCredentials) -> None:
         )
         return
 
-    if isinstance(gcs_credentials.gcsConfig, GCSValues):
+    if isinstance(gcs_credentials.gcsConfig, GcsCredentialsValues):
         if (
             gcs_credentials.gcsConfig.projectId
             and not gcs_credentials.gcsConfig.privateKey
@@ -121,12 +122,20 @@ def set_google_credentials(gcs_credentials: GCSCredentials) -> None:
             )
             return
         credentials_dict = build_google_credentials_dict(gcs_credentials.gcsConfig)
-
         tmp_credentials_file = create_credential_tmp_file(credentials=credentials_dict)
         os.environ[GOOGLE_CREDENTIALS] = tmp_credentials_file
         return
 
     raise InvalidGcsConfigException(
         f"Error trying to set GCS credentials with {gcs_credentials}."
-        " Check https://docs.open-metadata.org/openmetadata/connectors/database/bigquery "
+        " Check https://docs.open-metadata.org/connectors/database/bigquery "
     )
+
+
+def generate_http_basic_token(username, password):
+    """
+    Generates a HTTP basic token from username and password
+    Returns a token string (not a byte)
+    """
+    token = base64.b64encode(f"{username}:{password}".encode("utf-8")).decode("utf-8")
+    return token
